CHANGES
=======

0.8.0 (2020-09-08)
------------------
- Rewrite almost code
- Redesigned API
- Support unicode string for key
- Support flags
- Support URI
- More test coverage

0.7.0 (2020-08-28)
------------------
- Change pypi packages name to aiomemcached
- Drop python 3.4-3.6 support
- Add python 3.7+ support

0.6.0 (2017-12-03)
------------------

- Drop python 3.3 support

0.5.2 (2017-05-27)
------------------

- Fix issue with pool concurrency and task cancellation

0.5.1 (2017-03-08)
------------------

- Added MANIFEST.in

0.5.0 (2017-02-08)
------------------

- Added gets and cas commands

0.4.0 (2016-09-26)
------------------

- Make max_size strict #14

0.3.0 (2016-03-11)
------------------

- Dockerize tests

- Reuse memcached connections in Client Pool #4

- Fix stats parse to compatible more mc class software #5

0.2 (2015-12-15)
----------------

- Make the library Python 3.5 compatible

0.1 (2014-06-18)
----------------

- Initial release
